@@ -21,28 +21,14 @@ using namespace Kontact;
 #include <QStandardItemModel>
 
 K_PLUGIN_CLASS_WITH_JSON(KcmKontact, "data/kontactconfig.json")
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KcmKontact::KcmKontact(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , mPluginCombo(new QComboBox(parent))
-#else
-KcmKontact::KcmKontact(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KcmKontact::KcmKontact(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , mPluginCombo(new QComboBox(widget()))
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto topLayout = new QVBoxLayout(this);
-#else
     auto topLayout = new QVBoxLayout(widget());
-#endif
     auto pluginStartupLayout = new QHBoxLayout();
     topLayout->addLayout(pluginStartupLayout);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto forceStartupPluginCheckBox = new QCheckBox(Prefs::self()->forceStartupPluginItem()->label(), this);
-#else
     auto forceStartupPluginCheckBox = new QCheckBox(Prefs::self()->forceStartupPluginItem()->label(), widget());
-#endif
     forceStartupPluginCheckBox->setObjectName(QStringLiteral("kcfg_ForceStartupPlugin"));
     pluginStartupLayout->addWidget(forceStartupPluginCheckBox);
 
@@ -52,41 +38,28 @@ KcmKontact::KcmKontact(QObject *parent, const KPluginMetaData &data, const QVari
                                      "initial plugin each time Kontact is started. Otherwise, Kontact "
                                      "will restore the last active plugin from the previous usage."));
     connect(mPluginCombo, &QComboBox::currentIndexChanged, this, [this]() {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-        Q_EMIT changed(true);
-#else
-            markAsChanged();
-#endif
+        markAsChanged();
     });
     pluginStartupLayout->addWidget(mPluginCombo);
     pluginStartupLayout->addStretch();
     mPluginCombo->setEnabled(false);
 
     connect(forceStartupPluginCheckBox, &QAbstractButton::toggled, mPluginCombo, &QWidget::setEnabled);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto showSideBarCheckbox = new QCheckBox(Prefs::self()->sideBarOpenItem()->label(), this);
-#else
     auto showSideBarCheckbox = new QCheckBox(Prefs::self()->sideBarOpenItem()->label(), widget());
-#endif
     showSideBarCheckbox->setObjectName(QStringLiteral("kcfg_SideBarOpen"));
     topLayout->addWidget(showSideBarCheckbox);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    addConfig(Prefs::self(), this);
-#else
     addConfig(Prefs::self(), widget());
-#endif
     topLayout->addStretch();
     load();
 }
 
 void KcmKontact::load()
 {
-    const KConfigGroup grp(Prefs::self()->config(), "Plugins");
-    const QVector<KPluginMetaData> pluginMetaDatas =
-        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kontact"), [](const KPluginMetaData &data) {
-            return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
-        });
+    const KConfigGroup grp(Prefs::self()->config(), QStringLiteral("Plugins"));
+    const QList<KPluginMetaData> pluginMetaDatas = KPluginMetaData::findPlugins(QStringLiteral("pim6/kontact"), [](const KPluginMetaData &data) {
+        return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
+    });
 
     int activeComponent = 0;
     mPluginCombo->clear();
@@ -130,3 +103,5 @@ void KcmKontact::save()
 }
 
 #include "kcmkontact.moc"
+
+#include "moc_kcmkontact.cpp"
