@@ -31,6 +31,7 @@ using namespace Kontact;
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KColorSchemeManager>
+#include <KColorSchemeMenu>
 #include <KConfigGroup>
 #include <KDialogJobUiDelegate>
 #include <KEditToolBar>
@@ -82,14 +83,6 @@ MainWindow::MainWindow()
 
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/KontactInterface"), this, QDBusConnection::ExportScriptableSlots);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    // Set this to be the group leader for all subdialogs - this means
-    // modal subdialogs will only affect this dialog, not the other windows
-    setAttribute(Qt::WA_GroupLeader);
-#else
-#pragma "Port it"
-#endif
-
     initGUI();
     initObject();
 
@@ -98,7 +91,7 @@ MainWindow::MainWindow()
 
     factory()->plugActionList(this, QStringLiteral("navigator_actionlist"), mActionPlugins);
 
-    KConfigGroup grp(KSharedConfig::openConfig(), "MainWindow");
+    KConfigGroup grp(KSharedConfig::openConfig(), QStringLiteral("MainWindow"));
     KWindowConfig::restoreWindowSize(windowHandle(), grp);
     setAutoSaveSettings();
     mShowMenuBarAction->setChecked(Prefs::self()->showMenuBar());
@@ -142,10 +135,9 @@ void MainWindow::initObject()
             qFatal("KSycoca unavailable. Kontact will be unable to find plugins.");
         }
     }
-    mPluginMetaData =
-        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kontact"), [](const KPluginMetaData &data) {
-            return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
-        });
+    mPluginMetaData = KPluginMetaData::findPlugins(QStringLiteral("pim6/kontact"), [](const KPluginMetaData &data) {
+        return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
+    });
 
     // prepare the part manager
     mPartManager = new KParts::PartManager(this);
@@ -322,7 +314,7 @@ void MainWindow::setupActions()
     connect(mShowFullScreenAction, &QAction::toggled, this, &MainWindow::slotFullScreen);
 
     auto manager = new KColorSchemeManager(this);
-    actionCollection()->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+    actionCollection()->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
     mShowMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
 }
@@ -380,7 +372,7 @@ KontactInterface::Plugin *MainWindow::pluginFromName(const QString &identifier)
 void MainWindow::loadPlugins()
 {
     QList<KontactInterface::Plugin *> plugins;
-    KConfigGroup configGroup(Prefs::self()->config(), "Plugins");
+    KConfigGroup configGroup(Prefs::self()->config(), QStringLiteral("Plugins"));
     for (const KPluginMetaData &pluginMetaData : std::as_const(mPluginMetaData)) {
         if (!configGroup.readEntry(pluginMetaData.pluginId() + QLatin1String("Enabled"), pluginMetaData.isEnabledByDefault())) {
             continue;
@@ -457,7 +449,7 @@ void MainWindow::unloadDisabledPlugins()
 {
     // Only remove the now-disabled plugins.
     // Keep the other ones. loadPlugins() will skip those that are already loaded.
-    KConfigGroup configGroup(Prefs::self()->config(), "Plugins");
+    KConfigGroup configGroup(Prefs::self()->config(), QStringLiteral("Plugins"));
     for (const KPluginMetaData &pluginMetaData : std::as_const(mPluginMetaData)) {
         if (!configGroup.readEntry(pluginMetaData.pluginId() + QLatin1String("Enabled"), pluginMetaData.isEnabledByDefault())) {
             removePlugin(pluginMetaData.pluginId());
@@ -533,7 +525,7 @@ void MainWindow::addPlugin(KontactInterface::Plugin *plugin)
         action->setWhatsThis(i18nc("@info:whatsthis", "Switch to plugin %1", plugin->title()));
         action->setCheckable(true);
         action->setData(QVariant::fromValue(plugin)); // used by pluginActionWeightLessThan
-        connect(action, &QAction::triggered, this, [=]() {
+        connect(action, &QAction::triggered, this, [this, action, plugin]() {
             slotActionTriggered(action, plugin->identifier());
         });
         actionCollection()->addAction(plugin->identifier(), action);
@@ -780,7 +772,7 @@ void MainWindow::slotPreferences()
         });
 
         // Add the main contact KCM which is not associated with a specific plugin
-        dlg->addModule(KPluginMetaData(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/kontact/kcm_kontact")));
+        dlg->addModule(KPluginMetaData(QStringLiteral("pim6/kcms/kontact/kcm_kontact")));
 
         auto sortByWeight = [](const KPluginMetaData &m1, const KPluginMetaData &m2) {
             return m1.rawData().value(QStringLiteral("X-KDE-Weight")).toInt() < m2.rawData().value(QStringLiteral("X-KDE-Weight")).toInt();
@@ -903,7 +895,7 @@ void MainWindow::saveProperties(KConfigGroup &config)
 
     QStringList activePlugins;
 
-    KConfigGroup configGroup(Prefs::self()->config(), "Plugins");
+    KConfigGroup configGroup(Prefs::self()->config(), QStringLiteral("Plugins"));
     for (const KPluginMetaData &pluginMetaData : std::as_const(mPluginMetaData)) {
         if (!configGroup.readEntry(pluginMetaData.pluginId() + QLatin1String("Enabled"), pluginMetaData.isEnabledByDefault())) {
             KontactInterface::Plugin *plugin = pluginFromName(pluginMetaData.pluginId());
@@ -1025,3 +1017,5 @@ void MainWindow::setHelpText(QAction *action, const QString &text)
         action->setWhatsThis(text);
     }
 }
+
+#include "moc_mainwindow.cpp"
