@@ -32,11 +32,7 @@ IntroductionWebEnginePage::IntroductionWebEnginePage(QObject *parent)
     settings()->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
     settings()->setAttribute(QWebEngineSettings::AllowRunningInsecureContent, false);
     profile()->setPersistentCookiesPolicy(QWebEngineProfile::NoPersistentCookies);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const QFontInfo font(QFontDatabase().systemFont(QFontDatabase::GeneralFont));
-#else
     const QFontInfo font(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
-#endif
     settings()->setFontFamily(QWebEngineSettings::StandardFont, font.family());
     settings()->setFontSize(QWebEngineSettings::DefaultFontSize, font.pixelSize());
 }
@@ -53,3 +49,5 @@ bool IntroductionWebEnginePage::acceptNavigationRequest(const QUrl &url, Navigat
     Q_EMIT urlClicked(url);
     return false;
 }
+
+#include "moc_introductionwebenginepage.cpp"
